@@ -39,6 +39,8 @@ module Control.Monad.Logger
     , logWarnS
     , logErrorS
     , logOtherS
+    -- * TH util
+    , liftLoc
     ) where
 
 import Language.Haskell.TH.Syntax (Lift (lift), Q, Exp, Loc (..), qLocation)
@@ -154,6 +156,9 @@ logError = logTH LevelError
 logOther :: Text -> Q Exp
 logOther = logTH . LevelOther
 
+-- | Lift a location into an Exp.
+--
+-- Since 0.3.1
 liftLoc :: Loc -> Q Exp
 liftLoc (Loc a b c (d1, d2) (e1, e2)) = [|Loc
     $(lift a)
@@ -187,7 +192,7 @@ logOtherS = [|\src level msg -> monadLoggerLog $(qLocation >>= liftLoc) src (Lev
 
 -- | Monad transformer that disables logging.
 --
--- Since 0.3.0
+-- Since 0.2.4
 newtype NoLoggingT m a = NoLoggingT { runNoLoggingT :: m a }
 
 instance Monad m => Functor (NoLoggingT m) where
